Learn R Programming

clogitboost (version 1.1)

travel: Australian travel mode choice data

Description

The dataset is a survey result of 210 individuals' choices of travel mode between Sydney, Melbourne and New South Wales. There are four alternative choices, along with four choice-specific covaraites for each choice.

Usage

data("travel")

Arguments

Format

A data frame with 840 observations on the following 6 variables.
Group
index of the group membership.
MODE
binary outcome of whether the item is chosen.
TTME
terminal time.
INVC
in-vehicle cost.
INVT
amount of time spent traveling.
GC
genearlized cost of travel.

Greene W (2008). Econometric Analysis, 6th edition. Prentice Hall.